<?php

if (!defined('ABSPATH')) {
	header('Status: 403 Forbidden');
	header('HTTP/1.1 403 Forbidden');
	exit;
}

/**
 * Elementor widget.
 *
 * @since 1.0.0
 */

use Elementor\Controls_Manager;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;

class Elementor_XEl_Glitch_Headings extends \Elementor\Widget_Base
{

	/**
	 * Load scripts.
	 *
	 * Load script and stylesheet for the plugin.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget name.
	 */
	public function __construct($data = [], $args = null)
	{
		parent::__construct($data, $args);

		wp_register_script('xel-glitch-heading-script', XElGlitchHeading()->plugin_url() . '/assets/js/scripts.js', array('elementor-frontend', 'jquery'), XElGlitchHeading()->version(), true);
		wp_register_style('xel-glitch-heading-stylesheet', XElGlitchHeading()->plugin_url() . '/assets/css/styles' . (is_rtl() ? '-rtl' : '') . '.css', false, XElGlitchHeading()->version());
	}

	public function get_script_depends()
	{
		return ['xel-glitch-heading-script'];
	}

	public function get_style_depends()
	{
		return ['xel-glitch-heading-stylesheet'];
	}

	/**
	 * Get widget name.
	 *
	 * Retrieve this widget name.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'xel-glitch-heading';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve this widget title.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Glitch Heading', 'xel-glitch-heading');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve this widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-t-letter';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories this widget belongs to.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return array('general');
	}

	/**
	 * Register this widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'content_section',
			[
				'label' => __('Element controls', 'xel-glitch-heading'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		// Content
		$this->add_control(
			'content',
			[
				'label' => esc_html__('Heading', 'xel-glitch-heading'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 10,
				'dynamic' => ['active' => true],
				'default' => esc_html__('{Glitch} Heading', 'xel-glitch-heading'),
				'placeholder' => esc_html__('Heading', 'xel-glitch-heading'),
				'description' => esc_html__('Enter content. Example: {Glitch} Heading', 'xel-glitch-heading'),
			]
		);

		// HTML tag
		$this->add_control(
			'tag',
			[
				'label' => esc_html__('HTML Tag', 'xel-glitch-heading'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'div' => 'div',
					'span' => 'span',
					'p' => 'p',
				],
				'default' => 'h2',
			]
		);

		// Url
		$this->add_control(
			'link',
			[
				'label' => esc_html__('Link', 'xel-glitch-heading'),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__('https://xelementor.com', 'xel-glitch-heading'),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);

		$this->end_controls_section();

		// Style
		$this->start_controls_section('styles', ['label' => esc_html__('Styles', 'xel-glitch-heading'), 'tab' => Controls_Manager::TAB_STYLE,]);

		// Heading
		$this->start_controls_tabs('heading');

		$this->start_controls_tab(
			'tab_heading',
			[
				'label' => esc_html__('Heading', 'xel-glitch-heading')
			]
		);

		// Color
		$this->add_control(
			'color',
			[
				'label' => esc_html__('Color', 'xel-glitch-heading'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .xel-glitch-heading-title' => 'color: {{VALUE}}',
				],
			]
		);

		// Typography
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'label' => esc_html__('Typography', 'xel-glitch-heading'),
				'selector' => '{{WRAPPER}} .xel-glitch-heading-title',
			]
		);

		// Shadow
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'shadow',
				'label' => esc_html__('Shadow', 'xel-glitch-heading'),
				'selector' => '{{WRAPPER}} .xel-glitch-heading-title',
			]
		);

		// Alignment
		$this->add_responsive_control(
			'align',
			[
				'label' => esc_html__('Alignment', 'xel-glitch-heading'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__('Left', 'xel-glitch-heading'),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__('Center', 'xel-glitch-heading'),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__('Right', 'xel-glitch-heading'),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .xel-glitch-heading-title' => 'text-align: {{align}};',
				],
				'toggle' => true,
				'label_block' => false,
			]
		);

		$this->end_controls_tab();

		// Glitch
		$this->start_controls_tab(
			'tab_glitch',
			[
				'label' => esc_html__('Glitch', 'xel-glitch-heading')
			]
		);

		// Color #1
		$this->add_control(
			'color_glitch',
			[
				'label' => esc_html__('Color #1', 'xel-glitch-heading'),
				'type' => Controls_Manager::COLOR,
			]
		);


		// Color #2
		$this->add_control(
			'color_glitch_2',
			[
				'label' => esc_html__('Color #2', 'xel-glitch-heading'),
				'type' => Controls_Manager::COLOR,
			]
		);

		// Glitch magnitude
		$this->add_control(
			'magnitude',
			[
				'label' => esc_html__('Magnitude', 'xel-glitch-heading'),
				'type' => Controls_Manager::SELECT,
				'default' => 3,
				'options' => [
					2 => 10,
					3 => 8,
					4 => 6,
					5 => 4,
					6 => 2,
				]
			]
		);
		$this->end_controls_tab();

		$this->end_controls_section();
	}

	/**
	 * Render this widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$url = isset($settings['link']['url']) ? $settings['link']['url'] : "";

		$jsSettings = array(
			'color_glitch' => isset($settings['color_glitch']) ? $settings['color_glitch'] : "",
			'color_glitch_2' => isset($settings['color_glitch_2']) ? $settings['color_glitch_2'] : "",
			'magnitude' => isset($settings['magnitude']) ? intval($settings['magnitude']) : "",
		);

		$id = 'xel-' . $this->get_id();
?>
		<div id="<?php esc_attr_e($id); ?>" class="xel-glitch-heading" data-json="<?php echo esc_attr(wp_json_encode($jsSettings), ENT_QUOTES, 'UTF-8'); ?>">
			<<?php esc_attr_e($settings["tag"]); ?> class="xel-glitch-heading-title">
				<?php
				if (!empty($url)) {
				?>
					<a href="<?php echo esc_url($url); ?>">
					<?php
				}

				echo wp_kses_post(str_replace(array("{", "}"), array("<span class=\"xel-glitch-heading-effect\">", "</span>"), wp_strip_all_tags($settings['content'])));

				if (!empty($url)) {
					?>
					</a>
				<?php
				}
				?>
			</<?php esc_attr_e($settings["tag"]); ?>>
		</div>
<?php
	}
}
